=========================
:code:`Trakt['scrobble']`
=========================

.. automodule:: trakt.interfaces.scrobble

  .. autoclass:: ScrobbleInterface
    :members: action, pause, start, stop
    :undoc-members:
